Crate crate_crypto_internal_eth_kzg_polynomial

Crate crate_crypto_internal_eth_kzg_polynomial 

Modules

domain
poly_coeff

Structs

CosetFFT
CosetFFt contains a generator(coset) element that can be used to compute a coset FFT and its inverse which consequently can be used to compute a coset IFFT