Crate crate_crypto_internal_eth_kzg_polynomial
crate_
crypto_
internal_
eth_
kzg_
polynomial
0.6.0
All Items
Crate Items
Modules
Structs
Crate
crate_
crypto_
internal_
eth_
kzg_
polynomial
Modules

domain
poly_
coeff
Structs

CosetFFT
CosetFFt contains a generator(coset) element that can be used to compute a coset FFT and its inverse which consequently can be used to compute a coset IFFT